Module config

Module config 

👎Deprecated since 3.1.0: This crate will be REMOVED in Agave v4.0.0 and its name will be taken by the BPF Stake Program. Users of this crate’s public exports must switch to:
  • stake_state -> solana_stake_interface::state.
  • points -> solana_runtime::inflation_rewards::points.
  • id() / check_id() -> solana_stake_interface::program::_.
  • get_minimum_delegation() will continue to live at the same path.
  • Some convenience functions such as stake_from() and create_account() are removed.
config for staking carries variables that the stake program cares about

Structs

ConfigDeprecated

Constants

DEFAULT_SLASH_PENALTY
DEFAULT_WARMUP_COOLDOWN_RATE
ID
The const program ID.

Functions

add_genesis_accountDeprecated
check_idDeprecated
Returns true if given pubkey is the program ID.
create_accountDeprecated
fromDeprecated
idDeprecated
Returns the program ID.