get_minimum_delegation

Function get_minimum_delegation 

pub fn get_minimum_delegation(
    is_stake_raise_minimum_delegation_to_1_sol_active: bool,
) -> u64
👎Deprecated since 3.1.0:

This crate will be REMOVED in Agave v4.0.0 and its name will be taken by the BPF Stake Program. Users of this crate’s public exports must switch to:

  • stake_state -> solana_stake_interface::state.
  • points -> solana_runtime::inflation_rewards::points.
  • id() / check_id() -> solana_stake_interface::program::_.
  • get_minimum_delegation() will continue to live at the same path.
  • Some convenience functions such as stake_from() and create_account() are removed.
The minimum stake amount that can be delegated, in lamports. NOTE: This is also used to calculate the minimum balance of a delegated stake account, which is the rent exempt reserve plus the minimum stake delegation.