pub struct PointValue {
pub rewards: u64,
pub points: u128,
}๐Deprecated since 2.2.0
captures a rewards round as lamports to be awarded and the total points over which those lamports are to be distributed
Fields
rewards: u64๐Deprecated since 2.2.0
points: u128๐Deprecated since 2.2.0