👎Deprecated since 3.1.0: This crate will be REMOVED in Agave v4.0.0 and its name will be taken by the BPF Stake Program. Users of this crate’s public exports must switch to:
stake_state->solana_stake_interface::state.points->solana_runtime::inflation_rewards::points.id()/check_id()->solana_stake_interface::program::_.get_minimum_delegation()will continue to live at the same path.- Some convenience functions such as
stake_from()andcreate_account()are removed.
config for staking carries variables that the stake program cares about
Structs
- Config
Deprecated
Constants
- DEFAULT_
SLASH_ PENALTY - DEFAULT_
WARMUP_ COOLDOWN_ RATE - ID
- The const program ID.
Functions
- add_
genesis_ account Deprecated - check_
id Deprecated - Returns
trueif given pubkey is the program ID. - create_
account Deprecated - from
Deprecated - id
Deprecated - Returns the program ID.